@@ -6,7 +6,7 @@ from torchnorms.negations.base import BaseNegation
 
 class YagerNegation(BaseNegation):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
@@ -15,9 +15,15 @@ class YagerNegation(BaseNegation):
             self.p = nn.Parameter(torch.tensor(default_p))
         assert len(self.p.shape) == 0
 
+        self.eps = 0.01
+
     def __call__(self,
                  a: Tensor) -> Tensor:
         res: Optional[Tensor] = None
+
+        if self.p == 0:
+            self.p += self.eps
+
         res = torch.pow((1.0 - torch.pow(a,self.p)), 1.0 / self.p)
 
         return res
