@@ -10,7 +10,7 @@ from typing import Optional
 
 class HamacherTCoNorm(BaseTCoNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
