@@ -10,7 +10,7 @@ from typing import Optional
 
 class SchweizerSklarTCoNorm(BaseTCoNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
@@ -20,11 +20,17 @@ class SchweizerSklarTCoNorm(BaseTCoNorm):
 
         assert len(self.p.shape) == 0
 
+        self.eps += 0.001
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
 
             res: Optional[Tensor] = None
+
+            if self.p == 0:
+                self.p += self.eps
+
             p_1 = torch.pow(1.0 - a, self.p)
             p_2 = torch.pow(1.0 - b, self.p)
             p_1 = torch.maximum(torch.tensor(0), p_1 + p_2 - 1.0)
