@@ -10,7 +10,7 @@ from typing import Optional
 
 class WeberTCoNorm(BaseTCoNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
@@ -21,15 +21,19 @@ class WeberTCoNorm(BaseTCoNorm):
         else:
             assert self.p >= -1.0
 
-
-
         assert len(self.p.shape) == 0
 
+        self.relu = torch.nn.ReLU()
+
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
 
             res: Optional[Tensor] = None
+
+            self.p = self.relu(self.p) - 1
+
             p_1 = a + b
             p_2 = p_1 + (self.p * a * b)
             res = torch.minimum(p_2, torch.tensor(1))
