@@ -10,7 +10,7 @@ from typing import Optional
 
 class AczelAlsinaTNorm(BaseTNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
@@ -23,11 +23,17 @@ class AczelAlsinaTNorm(BaseTNorm):
 
         assert len(self.p.shape) == 0
 
+        self.relu = torch.nn.ReLU()
+        self.eps = 0.001
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
 
+        if self.p == 0:
+            self.p += self.eps
+
         p_1 = torch.pow(torch.abs(torch.log(a)), self.p)
         p_2 = torch.pow(torch.abs(torch.log(b)), self.p)
         res = torch.exp(-torch.pow(p_1 + p_2, 1.0 / self.p))
