@@ -8,9 +8,9 @@ from torchnorms.tnorms.base import BaseTNorm
 from typing import Optional
 
 
-class WeberTNorm(BaseTNorm):
+class DuboisTNorm(BaseTNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
@@ -18,10 +18,14 @@ class WeberTNorm(BaseTNorm):
             self.p = nn.Parameter(torch.tensor(default_p))
         assert len(self.p.shape) == 0
 
+
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
-        res = (a * b) / torch.maximum(torch.maximum(a,b), torch.tensor(self.p))
+
+        self.p = torch.clamp(res, min = 0, max = 1)
+        res = (a * b) / torch.maximum(torch.maximum(a,b), self.p)
 
         return res
