@@ -10,7 +10,7 @@ from typing import Optional
 
 class HamacherTNorm(BaseTNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 1.0) -> None:
         super().__init__()
         self.p = p
@@ -22,4 +22,5 @@ class HamacherTNorm(BaseTNorm):
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res = (a * b) / (self.p + (1.0 - self.p) * (a + b - a * b))
+
         return res
