@@ -10,7 +10,7 @@ from typing import Optional
 
 class WeberTNorm(BaseTNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = -0.8) -> None:
         super().__init__()
         self.p = p
@@ -22,13 +22,19 @@ class WeberTNorm(BaseTNorm):
 
         assert len(self.p.shape) == 0
 
+        self.relu = torch.nn.ReLU()
+
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
 
+        self.p = self.relu(self.p) - 1
+
         p_1 = (1.0 + self.p) * ( a + b - 1.0)
         p_2 = p_1 - self.p * a * b
         res = torch.maximum(p_2, torch.tensor(0))
 
+
         return res
