@@ -10,7 +10,7 @@ from typing import Optional
 
 class YagerTNorm(BaseTNorm):
     def __init__(self,
-                 p: Optional[Tensor],
+                 p: Optional[Tensor] = None,
                  default_p: float = 2.0) -> None:
         super().__init__()
         self.p = p
@@ -18,10 +18,19 @@ class YagerTNorm(BaseTNorm):
             self.p = nn.Parameter(torch.tensor(default_p))
         assert len(self.p.shape) == 0
 
+        self.relu = torch.nn.ReLU()
+        self.eps = 0.001
+
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
+
+
+        self.p = self.relu(self.p)
+        if self.p == 0:
+            self.p += self.eps
+
         p_1 = torch.pow(1.0 - a, self.p)
         p_2 = torch.pow(1.0 - b, self.p)
         p_3 = torch.pow(p_1 + p_2, 1.0 / self.p)
